@@ -120,7 +120,7 @@ pub(crate) fn convert_subfield_to_asm(
 
     // step 2
     let offset_in_words = check!(
-        descriptor.offset_to_field_name(field_to_access_name, field_to_access_span),
+        descriptor.offset_to_field_name(field_to_access_name, field_to_access_span.clone()),
         0,
         warnings,
         errors
@@ -154,6 +154,7 @@ pub(crate) fn convert_subfield_to_asm(
             return err(warnings, errors);
         }
     };
+
     asm_buf.push(if resolved_type_of_this_field.is_copy_type() {
         let offset_in_words = match VirtualImmediate12::new(offset_in_words, span.clone()) {
             Ok(o) => o,
