@@ -748,8 +748,6 @@ pub enum CompileError {
     },
     #[error("This type is invalid in a function selector. A contract ABI function selector must be a known sized type, not generic.")]
     InvalidAbiType { span: Span },
-    #[error("An ABI function must accept exactly four arguments.")]
-    InvalidNumberOfAbiParams { span: Span },
     #[error("This is a {actually_is}, not an ABI. An ABI cast requires a valid ABI to cast the address to.")]
     NotAnAbi {
         span: Span,
@@ -765,8 +763,6 @@ pub enum CompileError {
         provided_args: usize,
         span: Span,
     },
-    #[error("For now, ABI functions must take exactly four parameters, in this order: gas_to_forward: u64, coins_to_forward: u64, color_of_coins: b256, <your_function_parameter>: ?")]
-    AbiFunctionRequiresSpecificSignature { span: Span },
     #[error("This parameter was declared as type {should_be}, but argument of type {provided} was provided.")]
     ArgumentParameterTypeMismatch {
         span: Span,
@@ -849,6 +845,16 @@ pub enum CompileError {
         trait_name: String,
         span: Span,
     },
+    #[error(
+        "Contract ABI method parameter \"{param_name}\" is set multiple times for this contract ABI method call"
+    )]
+    ContractCallParamRepeated { param_name: String, span: Span },
+    #[error(
+        "Unrecognized contract ABI method parameter \"{param_name}\". The only available parameters are \"gas\", \"coins\", and \"asset_id\""
+    )]
+    UnrecognizedContractParam { param_name: String, span: Span },
+    #[error("Attempting to specify a contract method parameter for a non-contract function call")]
+    CallParamForNonContractCallMethod { span: Span },
 }
 
 impl std::convert::From<TypeError> for CompileError {
@@ -1024,11 +1030,9 @@ impl CompileError {
             TooManyArgumentsForFunction { span, .. } => span,
             TooFewArgumentsForFunction { span, .. } => span,
             InvalidAbiType { span, .. } => span,
-            InvalidNumberOfAbiParams { span, .. } => span,
             NotAnAbi { span, .. } => span,
             ImplAbiForNonContract { span, .. } => span,
             IncorrectNumberOfInterfaceSurfaceFunctionParameters { span, .. } => span,
-            AbiFunctionRequiresSpecificSignature { span, .. } => span,
             ArgumentParameterTypeMismatch { span, .. } => span,
             RecursiveCall { span, .. } => span,
             RecursiveCallChain { span, .. } => span,
@@ -1055,6 +1059,9 @@ impl CompileError {
             NameDefinedMultipleTimesForTrait { span, .. } => span,
             SupertraitImplMissing { span, .. } => span,
             SupertraitImplRequired { span, .. } => span,
+            ContractCallParamRepeated { span, .. } => span,
+            UnrecognizedContractParam { span, .. } => span,
+            CallParamForNonContractCallMethod { span, .. } => span,
         }
     }
 
