@@ -2,6 +2,7 @@ use std::collections::HashMap;
 use std::iter::FromIterator;
 
 use crate::{
+    asm_generation::from_ir::TypeAnalyzer,
     parse_tree::{AsmOp, AsmRegister, LazyOp, Literal, Visibility},
     semantic_analysis::{ast_node::TypedCodeBlock, ast_node::*, *},
     type_engine::*,
@@ -492,6 +493,7 @@ struct FnCompiler {
     current_block: Block,
     symbol_map: HashMap<String, String>,
     struct_names: StructSymbolMap,
+    type_analyzer: TypeAnalyzer,
 }
 
 impl FnCompiler {
@@ -512,6 +514,7 @@ impl FnCompiler {
             current_block: function.get_entry_block(context),
             symbol_map,
             struct_names,
+            type_analyzer: TypeAnalyzer::default(),
         }
     }
 
@@ -592,7 +595,8 @@ impl FnCompiler {
     ) -> Result<Value, String> {
         let span_md_idx = MetadataIndex::from_span(context, &ast_expr.span);
         match ast_expr.expression {
-            TypedExpressionVariant::Literal(l) => Ok(convert_literal_to_value(context, &l, span_md_idx)),
+            TypedExpressionVariant::Literal(l) =>
+                Ok(convert_literal_to_value(context, &l, span_md_idx)),
             TypedExpressionVariant::FunctionApplication {
                 name,
                 arguments,
@@ -680,8 +684,35 @@ impl FnCompiler {
             }
             TypedExpressionVariant::SizeOf { variant } => {
                 match variant {
-                    SizeOfVariant::Type(_) => unimplemented!(),
-                    SizeOfVariant::Val(exp) => self.compile_expression(context, *exp)
+                    SizeOfVariant::Type(type_id) => {
+                        let ir_type = convert_resolved_typeid_no_span(
+                            context, &mut self.struct_names, &type_id
+                        )?;
+                        Ok(Constant::get_uint(
+                            context,
+                            64,
+                            self.type_analyzer.ir_type_size_in_bytes(context, &ir_type),
+                            None
+                        ))
+                    }
+                    SizeOfVariant::Val(exp) => {
+                        let ir_type = convert_resolved_typeid(
+                            context,
+                            &mut self.struct_names,
+                            &exp.return_type,
+                            &exp.span
+                        )?;
+
+                        // Compile the expression in case of side-effects but ignore its value.
+                        self.compile_expression(context, *exp)?;
+
+                        Ok(Constant::get_uint(
+                            context,
+                            64,
+                            self.type_analyzer.ir_type_size_in_bytes(context, &ir_type),
+                            None
+                        ))
+                    }
                 }
             },
         }
