@@ -1,7 +1,7 @@
-use crate::Span;
-
 use super::scrutinee::Scrutinee;
 
+use sway_types::span::Span;
+
 #[derive(Debug, Clone)]
 pub(crate) enum MatchCondition {
     CatchAll(CatchAll),
