@@ -1,8 +1,10 @@
 mod enum_instantiation;
+mod func_app_instantiation;
 mod struct_expr_field;
 mod typed_expression;
 mod typed_expression_variant;
 pub(crate) use enum_instantiation::instantiate_enum;
+pub(crate) use func_app_instantiation::instantiate_function_application;
 pub(crate) use struct_expr_field::TypedStructExpressionField;
 pub(crate) use typed_expression::{error_recovery_expr, TypedExpression};
 pub(crate) use typed_expression_variant::*;
