@@ -1,12 +1,12 @@
 use super::{TypedCodeBlock, TypedExpression};
 
 #[derive(Clone, Debug)]
-pub(crate) struct TypedWhileLoop<'sc> {
-    pub(crate) condition: TypedExpression<'sc>,
-    pub(crate) body: TypedCodeBlock<'sc>,
+pub(crate) struct TypedWhileLoop {
+    pub(crate) condition: TypedExpression,
+    pub(crate) body: TypedCodeBlock,
 }
 
-impl<'sc> TypedWhileLoop<'sc> {
+impl TypedWhileLoop {
     pub(crate) fn pretty_print(&self) -> String {
         format!("while loop on {}", self.condition.pretty_print())
     }
