@@ -471,14 +471,12 @@ impl TypeInfo {
             }
         }
     }
+
     pub(crate) fn is_copy_type(&self) -> bool {
-        match self {
-            TypeInfo::UnsignedInteger(_) | TypeInfo::Boolean | TypeInfo::Byte => true,
-            TypeInfo::Tuple(fields) => fields
-                .iter()
-                .all(|field_type| look_up_type_id(*field_type).is_copy_type()),
-            _ => false,
-        }
+        matches!(
+            self,
+            TypeInfo::UnsignedInteger(_) | TypeInfo::Boolean | TypeInfo::Byte
+        )
     }
 
     pub fn is_uninhabited(&self) -> bool {
